@@ -27,6 +27,9 @@ TokenInfo decl_tokens[] = {
 	{Enum::Token::Type::DivEqual, Enum::Token::Kind::Assign, "DivEqual", "/="},
 	{Enum::Token::Type::ModEqual, Enum::Token::Kind::Assign, "ModEqual", "%="},
 	{Enum::Token::Type::StringAddEqual, Enum::Token::Kind::Assign, "StringAddEqual", ".="},
+	{Enum::Token::Type::LeftShiftEqual, Enum::Token::Kind::Assign, "LeftShiftEqual", "<<="},
+	{Enum::Token::Type::RightShiftEqual, Enum::Token::Kind::Assign, "RightShiftEqual", ">>="},
+	{Enum::Token::Type::StringMulEqual, Enum::Token::Kind::Assign, "StringMulEqual", "x="},
 	{Enum::Token::Type::GreaterEqual, Enum::Token::Kind::Operator, "GreaterEqual", ">="},
 	{Enum::Token::Type::LessEqual, Enum::Token::Kind::Operator, "LessEqual", "<="},
 	{Enum::Token::Type::EqualEqual, Enum::Token::Kind::Operator, "EqualEqual", "=="},
@@ -510,6 +513,9 @@ TokenInfo type_to_info[] = {
 	{Enum::Token::Type::DivEqual, Enum::Token::Kind::Assign, "DivEqual", "/="},
 	{Enum::Token::Type::ModEqual, Enum::Token::Kind::Assign, "ModEqual", "%="},
 	{Enum::Token::Type::StringAddEqual, Enum::Token::Kind::Assign, "StringAddEqual", ".="},
+	{Enum::Token::Type::LeftShiftEqual, Enum::Token::Kind::Assign, "LeftShiftEqual", "<<="},
+	{Enum::Token::Type::RightShiftEqual, Enum::Token::Kind::Assign, "RightShiftEqual", ">>="},
+	{Enum::Token::Type::StringMulEqual, Enum::Token::Kind::Assign, "StringMulEqual", "x="},
 	{Enum::Token::Type::GreaterEqual, Enum::Token::Kind::Operator, "GreaterEqual", ">="},
 	{Enum::Token::Type::LessEqual, Enum::Token::Kind::Operator, "LessEqual", "<="},
 	{Enum::Token::Type::EqualEqual, Enum::Token::Kind::Operator, "EqualEqual", "=="},
